pub mod player_count;
pub mod stats;

use serde::Deserialize;

pub trait PromMetric {
    fn to_metric_string(self: &Self) -> String;
}

pub const USER_AGENT: &str = "osrs-prometheus-exporter";

#[derive(Deserialize)]
struct GithubTag {
    name: String,
}

async fn get_runelite_version() -> eyre::Result<String> {
    let resp = reqwest::Client::new()
        .get("https://api.github.com/repos/runelite/runelite/tags")
        .header("User-Agent", USER_AGENT)
        .send()
        .await?
        .json::<Vec<GithubTag>>()
        .await?;

    if let Some(latest) = resp.first() {
        Ok(latest.name.replace("parent-", ""))
    } else {
        Err(eyre::eyre!("Failed to get github tags for runelite version"))
    }
}